Introduce
=========

| Hi! Thanks for comming my site.
| When you want to delete duplicate sentence from your sentence, Please
  use duplidele.

How to install
==============

pip install duplidele

How to coding
=============

| import duplidele as dd
| dd.exduplidele(“test sentence test sentence duplicate delete”, 5)

What is exported?
=================

| sys.argv[1] str: test sentence test sentence duplicate delete
| sys.argv[2] int: 5

last_sentence: test sentence duplicate delete

License
=======

MIT
